@@ -481,6 +481,7 @@ devalued.observations <- function(
    x,
    ...,
    fun = list(
+      mis ~ sum(is.na(x)),
       sum ~ sum(x, na.rm = TRUE),
       pct ~ signif(digits = 3,    sum / n * 100       ),
       ave ~ signif(digits = 3,   mean(x, na.rm = TRUE)),
@@ -614,7 +615,8 @@ widgets.devalued <- function(
     ),
    num = list(
       `Mean (SD)` ~ ave + ' (' + std + ')',
-      `Median (range)` ~ med + ' (' + min + ', ' + max + ')'
+      `Median (range)` ~ med + ' (' + min + ', ' + max + ')',
+      `Missing` ~ mis
    ),
    ...
 ){
@@ -788,6 +790,7 @@ groupwise <- function(x, ...)UseMethod('groupwise')
 groupwise.data.frame <- function(
    x,
    fun = list(
+      mis ~ sum(is.na(x)),
       sum ~ sum(x, na.rm = TRUE),
       pct ~ signif(digits = 3,    sum / n * 100    ),
       ave ~ signif(digits = 3,   mean(x, na.rm = TRUE)),
@@ -801,7 +804,8 @@ groupwise.data.frame <- function(
    ),
    num = list(
       `Mean (SD)` ~ ave + ' (' + std + ')',
-      `Median (range)` ~ med + ' (' + min + ', ' + max + ')'
+      `Median (range)` ~ med + ' (' + min + ', ' + max + ')',
+      `Missing` ~ mis
    ),
    ...
 ){
@@ -1488,6 +1492,7 @@ as_kable.tablet <- function(
 #'  na.rm = FALSE,
 #'  all = 'All',
 #'  fun = list(
+#'   mis ~ sum(is.na(x)),
 #'   sum ~ sum(x,  na.rm = TRUE),
 #'   pct ~ signif(digits = 3,     sum / n * 100        ),
 #'   ave ~ signif(digits = 3,    mean(x,  na.rm = TRUE)),
@@ -1501,7 +1506,8 @@ as_kable.tablet <- function(
 #'  ),
 #'  num = list(
 #'   `Mean (SD)` ~ ave + ' (' + std + ')',
-#'   `Median (range)` ~ med + ' (' + min + ', ' + max + ')'
+#'   `Median (range)` ~ med + ' (' + min + ', ' + max + ')',
+#'   `Missing` ~ mis
 #'   ),
 #'  lab = list(
 #'   lab ~ name + '\\n(N = ' + n + ')'
@@ -1556,7 +1562,20 @@ as_kable.tablet <- function(
 #'   select(-time, -year) %>%
 #'   mutate(sex = factor(sex), ulcer = factor(ulcer)) %>%
 #'   group_by(status) %>%
-#'   tablet
+#'   tablet %>%
+#'   as_kable
+#'   
+#' ## drop 'Missing', redefine 'range'
+#' melanoma %>%
+#'   select(-time, -year) %>%
+#'   mutate(sex = factor(sex), ulcer = factor(ulcer)) %>%
+#'   group_by(status) %>%
+#'   tablet(
+#'     Missing ~ NULL,
+#'     `Median (range)` ~ med + ' (' + min + ' to ' + max + ')'
+#'   ) %>%
+#'   as_kable
+#'   
 
 tablet.data.frame <- function(
    x,
@@ -1564,6 +1583,7 @@ tablet.data.frame <- function(
    na.rm = FALSE,
    all = 'All',
    fun = list(
+      mis ~ sum(is.na(x)),
       sum ~ sum(x, na.rm = TRUE),
       pct ~ signif(digits = 3,    sum / n * 100    ),
       ave ~ signif(digits = 3,   mean(x, na.rm = TRUE)),
@@ -1577,7 +1597,8 @@ tablet.data.frame <- function(
    ),
    num = list(
       `Mean (SD)` ~ ave + ' (' + std + ')',
-      `Median (range)` ~ med + ' (' + min + ', ' + max + ')'
+      `Median (range)` ~ med + ' (' + min + ', ' + max + ')',
+      `Missing` ~ mis
    ),
    lab = list(
      lab ~ name + '\n(N = ' + n + ')'
